"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const semver = require("semver");
const xml_1 = require("./xml");
exports.configNotFoundError = `config.xml NOT FOUND !\nTry to run the command from a cordova dir containing
 config.xml or run the help command to learn more on how specify the path to this directory`;
function updateVersion(version, directory) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!semver.valid(version)) {
            throw Error('This version is not valid. Please try to enter a valid version.');
        }
        if (semver.prerelease(version)) {
            throw Error('The config.xml should not contain a pre-released version. Please enter a released version.');
        }
        const configXml = getConfigXmlPath(directory);
        const config = yield xml_1.parse(configXml);
        config.widget.$.version = version;
        xml_1.write(configXml, config);
    });
}
exports.updateVersion = updateVersion;
function updatePackage(id, directory) {
    return __awaiter(this, void 0, void 0, function* () {
        const packageRegex = /^[A-Za-z]{2,6}((?!-)\.[A-Za-z0-9-]{1,63}(?!-))+$/i;
        if (!id.match(packageRegex)) {
            throw Error('This package id is not valid. Please try to enter a valid package identifier.');
        }
        const configXml = getConfigXmlPath(directory);
        const config = yield xml_1.parse(configXml);
        config.widget.$.id = id;
        xml_1.write(configXml, config);
    });
}
exports.updatePackage = updatePackage;
function updateName(name, directory) {
    return __awaiter(this, void 0, void 0, function* () {
        const configXml = getConfigXmlPath(directory);
        const config = yield xml_1.parse(configXml);
        config.widget.name = name;
        xml_1.write(configXml, config);
    });
}
exports.updateName = updateName;
function configExists(file) {
    return fs.existsSync(file);
}
exports.configExists = configExists;
function getVersion(directory) {
    return __awaiter(this, void 0, void 0, function* () {
        const configFile = yield xml_1.parse(getConfigXmlPath(directory));
        return configFile.widget.$.version;
    });
}
exports.getVersion = getVersion;
function getPackageId(directory) {
    return __awaiter(this, void 0, void 0, function* () {
        const configFile = yield xml_1.parse(getConfigXmlPath(directory));
        return configFile.widget.$.id;
    });
}
exports.getPackageId = getPackageId;
function getAppName(directory) {
    return __awaiter(this, void 0, void 0, function* () {
        const configFile = yield xml_1.parse(getConfigXmlPath(directory));
        return configFile.widget.name;
    });
}
exports.getAppName = getAppName;
function getConfigXmlPath(directory) {
    const filePath = path.join(directory, 'config.xml');
    if (!configExists(filePath)) {
        throw new Error(exports.configNotFoundError);
    }
    return filePath;
}
//# sourceMappingURL=configxml.js.map